responses

package module
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 3, 2023 License: MIT Imports: 2 Imported by: 42

README

responses

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CSSResponse

func CSSResponse(w http.ResponseWriter, r *http.Request, body string)

CSSResponse - responds with the CSS body

func CSSResponseF

func CSSResponseF(w http.ResponseWriter, r *http.Request, f func(w http.ResponseWriter, r *http.Request) string)

CSSResponseF - responds with the result from a string returning function

func GzipCSSResponse

func GzipCSSResponse(w http.ResponseWriter, r *http.Request, body string)

GzipCSSResponse - responds with the CSS body

func GzipCSSResponseF

func GzipCSSResponseF(w http.ResponseWriter, r *http.Request, f func(w http.ResponseWriter, r *http.Request) string)

GzipCSSResponse - responds with the result from a string returning function

func GzipHTMLResponse

func GzipHTMLResponse(w http.ResponseWriter, r *http.Request, body string)

GzipHTMLResponse - responds with the HTML body

func GzipHTMLResponseF

func GzipHTMLResponseF(w http.ResponseWriter, r *http.Request, f func(w http.ResponseWriter, r *http.Request) string)

GzipHTMLResponse - responds with the result from a string returning function

func GzipJSONResponse

func GzipJSONResponse(w http.ResponseWriter, r *http.Request, body string)

GzipJSONResponse - responds with the JSON body

func GzipJSONResponseF

func GzipJSONResponseF(w http.ResponseWriter, r *http.Request, f func(w http.ResponseWriter, r *http.Request) string)

GzipJSONResponse - responds with the result from a string returning function

func GzipJSResponse

func GzipJSResponse(w http.ResponseWriter, r *http.Request, body string)

GzipJSResponse - responds with the JS body

func GzipJSResponseF

func GzipJSResponseF(w http.ResponseWriter, r *http.Request, f func(w http.ResponseWriter, r *http.Request) string)

GzipJSResponse - responds with the result from a string returning function

func GzipXMLResponse

func GzipXMLResponse(w http.ResponseWriter, r *http.Request, body string)

GzipXMLResponse - responds with the XML body

func GzipXMLResponseF

func GzipXMLResponseF(w http.ResponseWriter, r *http.Request, f func(w http.ResponseWriter, r *http.Request) string)

GzipXMLResponse - responds with the result from a string returning function

func HTMLResponse

func HTMLResponse(w http.ResponseWriter, r *http.Request, body string)

HTMLResponse - responds with the HTML body

func HTMLResponseF

func HTMLResponseF(w http.ResponseWriter, r *http.Request, f func(w http.ResponseWriter, r *http.Request) string)

HTMLResponseF - responds with the result from a string returning function

func JSONResponse

func JSONResponse(w http.ResponseWriter, r *http.Request, body string)

JSONResponseF - responds with the JSON body

func JSONResponseF

func JSONResponseF(w http.ResponseWriter, r *http.Request, f func(w http.ResponseWriter, r *http.Request) string)

JSONResponseF - responds with the result from a string returning function

func JSResponse

func JSResponse(w http.ResponseWriter, r *http.Request, body string)

JSResponse - responds with the JS body

func JSResponseF

func JSResponseF(w http.ResponseWriter, r *http.Request, f func(w http.ResponseWriter, r *http.Request) string)

JSResponseF - responds with the result from a string returning function

func XMLResponse

func XMLResponse(w http.ResponseWriter, r *http.Request, body string)

XMLResponse - responds with the result from a string returning function

func XMLResponseF

func XMLResponseF(w http.ResponseWriter, r *http.Request, f func(w http.ResponseWriter, r *http.Request) string)

XMLResponseF - responds with the result from a string returning function

Types

This section is empty.

Jump to